@@ -6,10 +6,12 @@ from simpleeval import SimpleEval, DEFAULT_FUNCTIONS
 g_s = SimpleEval()
 g_s.functions = DEFAULT_FUNCTIONS.copy()
 
+
 def chunk_list(values: list, num: int):
     for i in range(0, len(values), num):
         yield values[i: i+num]
 
+
 # 转换类为字典
 def convert_class_to_dict(obeject_class):
     object_value = {}
@@ -19,12 +21,23 @@ def convert_class_to_dict(obeject_class):
             object_value[key] = value
     return object_value
 
+
 def generate_object_id():
     return bson.ObjectId().__str__()
 
+
 def remove_exponent(value: Decimal):
     return value.to_integral() if value == value.to_integral() else value.normalize()
 
+
+def remove_exponent_str(value: str) -> str:
+    dec_value = Decimal(value)
+    if dec_value == dec_value.to_integral(): # int
+        return str(int(float(value)))
+    else:
+        return value.rstrip('0')
+
+
 def is_number(value: str):
     try:
         return True, float(value)
@@ -32,15 +45,17 @@ def is_number(value: str):
         pass
     return False, value
 
+
 '''
 "v+20"  #基础方法 + - * / %  == < > <= >= >> <<
 "int(v)" #基础函数 randint rand int float str
 "com(v)"   #自定义函数 bit signed inverse_long inverse_float inverse_double
 "1 if v == 20.1234 else 0" #表达式
 '''
-def format_value(value_old: str, scale: str, decimal: int = 2) -> str:
+def format_value(value_old: str, scale: str='1', decimal: int = 2) -> str:
     value = str(value_old)
-    scale_num, scale = is_number(str(scale))
+    scale = '1' if scale == '' else scale
+    is_scale_num, scale = is_number(str(scale))
     if len(value) > 0:
         try:
             if value.lower() in ['true', 'active']:
@@ -48,9 +63,9 @@ def format_value(value_old: str, scale: str, decimal: int = 2) -> str:
             elif value.lower() in ['false', 'inactive']:
                 value = '0'
 
-            value_num, value = is_number(str(value))
-            if value_num is True:
-                if scale_num:
+            is_value_num, value = is_number(str(value))
+            if is_value_num is True:
+                if is_scale_num:
                     if scale != float('1'):
                         value = value * scale
                 else:
@@ -58,11 +73,13 @@ def format_value(value_old: str, scale: str, decimal: int = 2) -> str:
                         g_s.names = {'v': value}
                         value = g_s.eval(scale)
 
-                value_num, value = is_number(str(value))
-                if value_num is True:
-                    format = f"%.{decimal}f"
-                    value = format % value  # 格式化小数点
-                    value = remove_exponent(Decimal(value))
+                is_value_num, value = is_number(str(value))
+                if is_value_num is True:
+                    d = Decimal(str(value))
+                    if -d.as_tuple().exponent > decimal:
+                        format = f"%.{decimal}f"
+                        value = format % value  # 格式化小数点
+                    value = remove_exponent_str(str(value))
             return str(value)
         except Exception as e:
             pass
