@@ -10,11 +10,11 @@ def check_is_ip(ip: str):
     return False
 
 #格式化数字字母以外的字符 \u4e00-\u9fa5_
-def format_name(name: str, pattern: str=r'[^a-zA-Z0-9_]+'):
+def format_name(name: str, pattern: str=r'[^a-zA-Z0-9_]+', replace: str='_'):
     if name is None:
         return ''
     else:
-        return re.sub(r'^_|_$', '', re.sub(pattern, '_', name.strip()))
+        return re.sub(r'^_|_$', '', re.sub(pattern, replace, name.strip()))
 
 def format_value(value: Any, mapping: dict={}, decimal: int=3):
     if isinstance(value, str):
