@@ -24,4 +24,10 @@ def test_format_value2():
     print(format_value('2', '_or(bit(v, 1), bit(v, 0), _and(bit(v, 0),bit(v, 1)))'))
 
 
-test_format_value2()
\ No newline at end of file
+def test_float_value():
+    values = ['123456789.0', '-123456789.0', '9.0', '9.1', '9.12334567', '-9.0', '-9.12300000', '-0.00000567', '-0.000005670001000']
+    for value in values:
+        print(f"{value} {format_value(value, '1', 7)}")
+    print()
+
+test_float_value()
\ No newline at end of file
