@@ -1,5 +1,6 @@
 from robertcommonbasic.basic.dt.utils import datetime, convert_time, get_datetime, convert_time_by_timezone, get_timezone, parse_time, get_datetime_from_stamp, convert_time_with_timezone
-
+from datetime import timezone
+import pytz
 
 def test_time():
     nt = datetime.now()
@@ -29,6 +30,12 @@ def test_parse_time():
 
 
 def test_timestamp():
+    tm = 1653039214
+    data_time = convert_time(tm, 'UTC', 'Asia/Shanghai').replace(second=0).strftime(
+        "%Y-%m-%d %H:%M:%S")
+
+    data_time1 = datetime.fromtimestamp(tm, tz=timezone.utc).replace(second=0).astimezone( tz=pytz.timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S")
+
     print(convert_time(get_datetime(), 'Asia/Shanghai', 'UTC'))
     print(convert_time(get_datetime('UTC'), 'Asia/Shanghai', 'Asia/Shanghai'))
     print(convert_time(get_datetime('Asia/Shanghai'), 'UTC', 'UTC'))
